IF EXISTS 
( 
    SELECT 1 FROM sysobjects WHERE name = 'sp_datetime_formats' 
) 
DROP PROCEDURE sp_datetime_formats 
GO 
CREATE PROCEDURE sp_datetime_formats 
AS 
BEGIN 
    /*******************************************************************************************
    sp_datetime_formats

    Written By:    Doug Deneau, FinServ Technology Services, PLC (Fettan)
    Company Desc:  Payment services technology company in Ethoipia
    Date Written:  March, 2009
    Website:       www.GoFettan.com

    This stored procedure is used to generate all datetime formats when using the
    CONVERT(varchar(30),@MyDate,<style>) function.  It shows sample formats of each
    variation in style parameter.  The output also shows samples for the various
    date arguments within the date functions.

    INPUT PARAMTERS
    ---------------
    <none>

    OUTPUT DATA
    -----------
    WO_Century          - Style argument value without the century in the year (2-digit year)
    WO_Cent_No_Offset   - Sample output without the century in the year and no offset
    WO_Cent_With_Offset - Sample output without the century in the year and offset
    W_Century           - Style argument value with the century in the year (4-digit year)
    W_Cent_No_Offset    - Sample output with the century in the year and no offset
    W_Cent_With_Offset  - Sample output with the century in the year and offset
    DateName_Parm       - Date Part argument name for use in various date functions
    DateName_Example    - Sample data from using the corresponding Date Part argument

    MODIFICATION LOG
    ----------------
    <name> - <datetime> - <description of change>

    ********************************************************************************************/ 
    SET NOCOUNT ON 
    DECLARE @Fmt int , 
    @More char ( 1 ) , 
    @Today datetime , 
    @TodayO datetimeoffset 

    SELECT @Today = getdate ( ) 

    SELECT @TodayO = SYSDATETIMEOFFSET ( ) 

    CREATE TABLE #data 
    ( WO_Century varchar ( 5 ) NULL , 
        WO_Cent_No_Offset varchar ( 50 ) NULL , 
        WO_Cent_With_Offset varchar ( 50 ) NULL , 
        W_Century int NOT NULL , 
        W_Cent_No_Offset varchar ( 50 ) NULL , 
        W_Cent_With_Offset varchar ( 50 ) NULL , 
        DateName_Parm varchar ( 50 ) NULL , 
        DateName_Example varchar ( 50 ) NULL ) 

    SELECT 
    @More = 'Y' , 
    @Fmt = 0 

    WHILE @More = 'Y' 
    BEGIN 
        INSERT INTO #data ( WO_Century , WO_Cent_No_Offset , WO_Cent_With_Offset , W_Century , W_Cent_No_Offset , W_Cent_With_Offset ) 
        SELECT 
        @Fmt , 
        convert ( varchar ( 50 ) , @Today , @Fmt ) , 
        convert ( varchar ( 50 ) , @TodayO , @Fmt ) , 
        @Fmt + 100 , 
        convert ( varchar ( 50 ) , @Today , @Fmt + 100 ) , 
        convert ( varchar ( 50 ) , @TodayO , @Fmt + 100 ) 

        SELECT @Fmt = @Fmt + 1 

        IF @Fmt > 14 
        SELECT @More = 'N' 

    END 
    -- of loop
    INSERT INTO #data ( WO_Century , WO_Cent_No_Offset , WO_Cent_With_Offset , W_Century , W_Cent_No_Offset , W_Cent_With_Offset ) 
    SELECT 
    20 , 
    convert ( varchar ( 50 ) , @Today , 20 ) , 
    convert ( varchar ( 50 ) , @TodayO , 20 ) , 
    120 , 
    convert ( varchar ( 50 ) , @Today , 120 ) , 
    convert ( varchar ( 50 ) , @TodayO , 120 ) 

    INSERT INTO #data ( WO_Century , WO_Cent_No_Offset , WO_Cent_With_Offset , W_Century , W_Cent_No_Offset , W_Cent_With_Offset ) 
    SELECT 
    21 , 
    convert ( varchar ( 50 ) , @Today , 21 ) , 
    convert ( varchar ( 50 ) , @TodayO , 21 ) , 
    121 , 
    convert ( varchar ( 50 ) , @Today , 121 ) , 
    convert ( varchar ( 50 ) , @TodayO , 121 ) 

    INSERT INTO #data ( W_Century , W_Cent_No_Offset , W_Cent_With_Offset ) 
    SELECT 
    126 , 
    convert ( varchar ( 50 ) , @Today , 126 ) , 
    convert ( varchar ( 50 ) , @TodayO , 126 ) 

    INSERT INTO #data ( W_Century , W_Cent_No_Offset , W_Cent_With_Offset ) 
    SELECT 
    127 , 
    convert ( varchar ( 50 ) , @Today , 127 ) , 
    convert ( varchar ( 50 ) , @TodayO , 127 ) 

    INSERT INTO #data ( W_Century , W_Cent_No_Offset , W_Cent_With_Offset ) 
    SELECT 
    130 , 
    convert ( varchar ( 50 ) , @Today , 130 ) , 
    convert ( varchar ( 50 ) , @TodayO , 130 ) 

    INSERT INTO #data ( W_Century , W_Cent_No_Offset , W_Cent_With_Offset ) 
    SELECT 
    131 , 
    convert ( varchar ( 50 ) , @Today , 131 ) , 
    convert ( varchar ( 50 ) , @TodayO , 131 ) 

    UPDATE #data SET WO_Century = '<def>' WHERE WO_Century = '0' 

    -- datepart formats

    UPDATE #data SET DateName_Parm = 'year,yyyy,yy' , DateName_Example = datename ( year , @Today ) WHERE WO_Century = '0' 
    UPDATE #data SET DateName_Parm = 'quarter,qq,q' , DateName_Example = datename ( quarter , @Today ) WHERE WO_Century = '1' 
    UPDATE #data SET DateName_Parm = 'month,mm,m' , DateName_Example = datename ( month , @Today ) WHERE WO_Century = '2' 
    UPDATE #data SET DateName_Parm = 'dayofyear,dy,y' , DateName_Example = datename ( dayofyear , @Today ) WHERE WO_Century = '3' 
    UPDATE #data SET DateName_Parm = 'day,dd,d' , DateName_Example = datename ( day , @Today ) WHERE WO_Century = '4' 
    UPDATE #data SET DateName_Parm = 'week,wk,ww' , DateName_Example = datename ( week , @Today ) WHERE WO_Century = '5' 
    UPDATE #data SET DateName_Parm = 'weekday,dw' , DateName_Example = datename ( weekday , @Today ) WHERE WO_Century = '6' 
    UPDATE #data SET DateName_Parm = 'hour,hh' , DateName_Example = datename ( hour , @Today ) WHERE WO_Century = '7' 
    UPDATE #data SET DateName_Parm = 'minute,mi,mn' , DateName_Example = datename ( minute , @Today ) WHERE WO_Century = '8' 
    UPDATE #data SET DateName_Parm = 'second,ss,s' , DateName_Example = datename ( second , @Today ) WHERE WO_Century = '9' 
    UPDATE #data SET DateName_Parm = 'millisecond,ms' , DateName_Example = datename ( millisecond , @Today ) WHERE WO_Century = '10' 
    UPDATE #data SET DateName_Parm = 'microsecond,mcs' , DateName_Example = datename ( microsecond , @Today ) WHERE WO_Century = '11' 
    UPDATE #data SET DateName_Parm = 'nanosecond,ns' , DateName_Example = datename ( nanosecond , @Today ) WHERE WO_Century = '12' 
    UPDATE #data SET DateName_Parm = 'TZoffset,tz' , DateName_Example = datename ( TZOFFSET , @TodayO ) WHERE WO_Century = '13' 

    SELECT * FROM #data 

    DROP TABLE #data 

END 
-- of procedure
GO